#ifndef BROWSERTREEDBUSEXTENSION_H
#define BROWSERTREEDBUSEXTENSION_H

#include <QObject>
#include <qudbusplugininterface.h>
#include <appinfo.h>

class BrowserTreeDBusExtension : public QObject, public QuAppDBusControllerListener
{
    Q_OBJECT
public:
    BrowserTreeDBusExtension(BrowserTree *tree);

    virtual ~BrowserTreeDBusExtension();

    void setApplicationsRunning(const QList<AppInfo> &ail);

    bool isCumbiaApp(const QString& exename) const;


public slots:

    bool dbusRaiseCumbia(const QString& commandLine);
    void dbusStopQTangoCumbia(const QString& commandLine);

    /* retrieve the list of registered applications */
    QList<AppInfo> refreshList();

    AppInfo findApp(const QString& commandLine);

private slots:
    void newApplicationRegisteredToBus(const TAppInfo& appInfo);
    void applicationUnregisteredFrom(const TAppInfo &appInfo);

private:
    BrowserTree *m_tree;

    void m_loadCumbiaPlugin();

    void m_extractInfo(const AppInfo &ai, QString& anam, QStringList& args, QString& dbus_service_name) const;

    void m_newApplicationLaunched(const AppInfo&);
    void m_applicationClosed(const AppInfo &);

    bool m_quapp_in_this_display(const QuAppInfo& ai);
    bool m_qtango_app_in_this_display(const TAppInfo &ai);

    QuAppDBusControllerInterface *m_qudbusctrl_i;

public:
    // QuAppDBusControllerListener interface
    void onAppRegistered(const QuAppInfo &ai);
    void onAppUnregistered(const QuAppInfo &qai);
};

#endif // BROWSERTREEDBUSEXTENSION_H
